# App_ANN_Project
App_ANN_Project

#Reference
[official python docs](https://packaging.python.org/tutorials/packaging-projects/)
[github docs for github actions](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)